@@ -182,9 +182,6 @@ setup_dialog (GsmAppDialog *dialog)
         gtk_container_add (GTK_CONTAINER (content_area), widget);
 
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-#endif
         gtk_window_set_icon_name (GTK_WINDOW (dialog), "mate-session-properties");
 
         g_object_set (dialog,
@@ -258,7 +255,9 @@ gsm_app_dialog_constructor (GType                  type,
 
         setup_dialog (dialog);
 
+#if !GTK_CHECK_VERSION (3, 14, 0)
         gtk_widget_show_all (GTK_WIDGET (dialog));
+#endif
 
         return G_OBJECT (dialog);
 }
@@ -480,7 +479,6 @@ gsm_app_dialog_run (GsmAppDialog  *dialog,
                 GError     *error;
                 char      **argv;
                 int         argc;
-                gboolean   UNUSED_VARIABLE changed;
 
                 name = gsm_app_dialog_get_name (GSM_APP_DIALOG (dialog));
                 exec = gsm_app_dialog_get_command (GSM_APP_DIALOG (dialog));
@@ -521,8 +519,6 @@ gsm_app_dialog_run (GsmAppDialog  *dialog,
                         continue;
                 }
 
-                changed = FALSE;
-
                 if (gsm_util_text_is_blank (name)) {
                         name = argv[0];
                 }
