@@ -31,7 +31,6 @@
 
 #include "gsm-properties-dialog.h"
 #include "gsm-app-dialog.h"
-#include "eggdesktopfile.h"
 #include "gsm-util.h"
 #include "gsp-app.h"
 #include "gsp-app-manager.h"
@@ -603,7 +602,6 @@ setup_dialog (GsmPropertiesDialog *dialog)
         /* we don't want to accept drags coming from this widget */
         targetlist = gtk_drag_dest_get_target_list (GTK_WIDGET (treeview));
         if (targetlist != NULL) {
-#if GTK_CHECK_VERSION (3, 0, 0)
                 GtkTargetEntry *targets;
                 gint n_targets;
                 gint i;
@@ -614,16 +612,6 @@ setup_dialog (GsmPropertiesDialog *dialog)
                 gtk_drag_dest_set_target_list (GTK_WIDGET (treeview), targetlist);
                 gtk_target_list_unref (targetlist);
                 gtk_target_table_free (targets, n_targets);
-#else
-                GList *list;
-                list = targetlist->list;
-                while (list != NULL) {
-                        GtkTargetPair *targetpair;
-                        targetpair = list->data;
-                        targetpair->flags = GTK_TARGET_OTHER_WIDGET;
-                        list = list->next;
-                }
-#endif
         }
 
         g_signal_connect (treeview, "drag_begin",
@@ -714,7 +702,9 @@ gsm_properties_dialog_constructor (GType                  type,
 
         setup_dialog (dialog);
 
+#if !GTK_CHECK_VERSION (3, 14, 0)
         gtk_widget_show (GTK_WIDGET (dialog));
+#endif
 
         return G_OBJECT (dialog);
 }
@@ -790,9 +780,6 @@ gsm_properties_dialog_init (GsmPropertiesDialog *dialog)
         gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
         gtk_box_set_spacing (GTK_BOX (content_area), 2);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-#endif
         gtk_window_set_icon_name (GTK_WINDOW (dialog), "mate-session-properties");
         gtk_window_set_title (GTK_WINDOW (dialog), _("Startup Applications Preferences"));
 }
