@@ -39,6 +39,8 @@
 #include <dbus/dbus-glib-bindings.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include <libmate-desktop/mate-gsettings.h>
+
 #include "mdm-signal-handler.h"
 #include "mdm-log.h"
 
@@ -61,6 +63,9 @@
 #define ACCESSIBILITY_KEY     "accessibility"
 #define ACCESSIBILITY_SCHEMA  "org.mate.interface"
 
+#define DEBUG_SCHEMA          "org.mate.debug"
+#define DEBUG_KEY             "mate-session"
+
 #define VISUAL_SCHEMA         "org.mate.applications-at-visual"
 #define VISUAL_KEY            "exec"
 #define VISUAL_STARTUP_KEY    "startup"
@@ -249,15 +254,16 @@ static void append_required_apps(GsmManager* manager)
 	{
 		g_warning("No required applications specified");
 	}
-
-	for (i = 0; required_components[i]; i++)
+	else
 	{
+		for (i = 0; required_components[i]; i++)
+		{
 			char* default_provider;
 			const char* component;
 
 			if (IS_STRING_EMPTY((char*) required_components[i]))
 			{
-					continue;
+				continue;
 			}
 
 			component = required_components[i];
@@ -285,6 +291,7 @@ static void append_required_apps(GsmManager* manager)
 			}
 
 			g_free(default_provider);
+		}
 	}
 
 	g_debug("main: *** Done adding required apps");
@@ -524,18 +531,21 @@ static gboolean require_dbus_session(int argc, char** argv, GError** error)
 	return TRUE;
 }
 
+void debug_changed (GSettings *settings, gchar *key, gpointer user_data)
+{
+	debug = g_settings_get_boolean (settings, DEBUG_KEY);
+	mdm_log_set_debug (debug);
+}
+
 int main(int argc, char** argv)
 {
 	struct sigaction sa;
 	GError* error;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	const char* display_str;
-#else
-	char* display_str;
-#endif
 	GsmManager* manager;
 	GsmStore* client_store;
 	GsmXsmpServer* xsmp_server;
+	GSettings* debug_settings = NULL;
 	GSettings* accessibility_settings;
 	MdmSignalHandler* signal_handler;
 	static char** override_autostart_dirs = NULL;
@@ -579,20 +589,25 @@ int main(int argc, char** argv)
 	}
 
 	mdm_log_init();
+
+	/* Allows to enable/disable debug from GSettings only if it is not set from argument */
+	if (!debug && mate_gsettings_schema_exists(DEBUG_SCHEMA))
+	{
+		debug_settings = g_settings_new (DEBUG_SCHEMA);
+		g_signal_connect (debug_settings, "changed::" DEBUG_KEY, G_CALLBACK (debug_changed), NULL);
+		debug = g_settings_get_boolean (debug_settings, DEBUG_KEY);
+	}
+
 	mdm_log_set_debug(debug);
 
+	if (g_getenv ("XDG_CURRENT_DESKTOP") == NULL)
+		gsm_util_setenv ("XDG_CURRENT_DESKTOP", "MATE");
+
 	/* Set DISPLAY explicitly for all our children, in case --display
 	 * was specified on the command line.
 	 */
-#if GTK_CHECK_VERSION (3, 0, 0)
 	display_str = gdk_display_get_name (gdk_display_get_default());
-#else
-	display_str = gdk_get_display();
-#endif
 	gsm_util_setenv("DISPLAY", display_str);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	g_free(display_str);
-#endif
 
 	/* Some third-party programs rely on MATE_DESKTOP_SESSION_ID to
 	 * detect if MATE is running. We keep this for compatibility reasons.
@@ -667,6 +682,11 @@ int main(int argc, char** argv)
 		g_object_unref(client_store);
 	}
 
+	if (debug_settings != NULL)
+	{
+		g_object_unref(debug_settings);
+	}
+
 	msm_gnome_stop();
 	mdm_log_shutdown();
 
